# Isostatic
A repository for designing isostatic structures

# Es
Un repositorio para diseño de estructuras isostaticas mediante un paquete de python. 

# Licencia
Este repositorio no tiene licencia, si desea informacion por favor contactese al correo: jimenezhuancarodrigo@gmail.com para proporcionale una licencia personal a su persona

# Modulos
- Point (2D)
- Support (vertical, horizontal, momentos)

# Instalacion
Todavia no disponible


